@@ -46,9 +46,10 @@ from contextlib import contextmanager
 import msgpack
 import pylibmc
 
-VERSION = "0.5.3"
+VERSION = "0.6.0"
 LOCK_SH = 0
 LOCK_EX = 1
+CACHE_SOCKET = "/tmp/cache.starrydb"
 
 class StarryError(Exception):
     '''StarryError'''
@@ -178,13 +179,32 @@ class LibMemcachedClient(pylibmc.ThreadMappedPool):
             return mc.delete(key)
 
 class StarryServer(object):
-    def __init__(self, address, depots=[], log_file=None, rw_ratio=5):
+    def __init__(self, address, depots=[], cache_size=0, log_file=None, rw_ratio=5):
         self.address = address
+        self.cursor = 0
         self.depots = {}
         self.logger = StarryLog(log_file) if log_file is not None else None
         self.rw_ratio = rw_ratio
+        self.cache = None
 
-        if type(self.address) is str:
+        if int(cache_size) > 0:
+            try:
+                subprocess.check_output(f"fuser -k {CACHE_SOCKET}", shell=True, stderr=subprocess.STDOUT, universal_newlines=True)
+            except:
+                pass
+
+            try:
+                os.system(f"memcached -d -u root -a 0777 -D : -C -m {int(cache_size)} -s {CACHE_SOCKET}")
+
+                time.sleep(1)
+
+                self.cache = LibMemcachedClient(CACHE_SOCKET)
+            except Exception as e:
+                self.logger.error(f"Caught exception: {e.__doc__}({e})")
+
+                self.cache = None
+
+        if os.path.isfile(self.address) is True:
             try:
                 os.remove(self.address)
             except:
@@ -194,12 +214,25 @@ class StarryServer(object):
             if "path" in depot:
                 depot_path = os.path.abspath(depot["path"])
 
-                self.depots[depot_path] = StarryDepot(depot_path, self.address, self.logger, self.rw_ratio, depot.get("cache", 0))
+                self.depots[depot_path] = StarryDepot(depot_path, self.address, self.logger, self.rw_ratio, self.cursor, self.cache if depot.get("cache", False) is True else None)
+
+                self.cursor += 1
 
     def __del__(self):
         self.depots.clear()
 
-        if type(self.address) is str:
+        if self.cache is not None:
+            try:
+                self.cache.flush_all()
+            except:
+                pass
+
+            try:
+                subprocess.check_output(f"fuser -k {CACHE_SOCKET}", shell=True, stderr=subprocess.STDOUT, universal_newlines=True)
+            except:
+                pass
+
+        if os.path.isfile(self.address) is True:
             try:
                 os.remove(self.address)
             except:
@@ -225,7 +258,9 @@ class StarryServer(object):
                         (depot, mode) = conn.recv()
 
                         if depot not in self.depots:
-                            self.depots[depot] = StarryDepot(depot, self.address, self.logger, self.rw_ratio)
+                            self.depots[depot] = StarryDepot(depot, self.address, self.logger, self.rw_ratio, self.cursor)
+
+                            self.cursor += 1
 
                         executor.submit(self.depots[depot].executeCommand, conn, mode)
                     except Exception as e:
@@ -237,11 +272,12 @@ class StarryServer(object):
                             pass
 
 class StarryDepot(object):
-    def __init__(self, path, server, logger, rw_ratio, cache_size=0):
+    def __init__(self, path, server, logger, rw_ratio, index, cache=None):
         self.database = pathlib.Path(path)
         self.logger = logger
         self.rw_ratio = rw_ratio
-        self.cache = None
+        self.index = index
+        self.cache = cache
         self.thread_cond = threading.Condition()
         self.thread_lock = threading.RLock()
         self.write_wait = 0
@@ -252,8 +288,6 @@ class StarryDepot(object):
         if not self.database.is_dir():
             raise StarryError(f"path {path} doesn't exist.")
 
-        self.setCache(cache_size)
-
         if not self.database.joinpath(".backup").is_dir():
             self.database.joinpath(".backup").mkdir(exist_ok=True)
 
@@ -262,8 +296,6 @@ class StarryDepot(object):
         self.database.joinpath(".starrydb").write_bytes(msgpack.packb(server))
 
     def __del__(self):
-        self.clearCache()
-
         try:
             self.database.joinpath(".starrydb").unlink()
         except:
@@ -319,40 +351,6 @@ class StarryDepot(object):
         except:
             pass
 
-    def setCache(self, cache_size):
-        if int(cache_size) > 0:
-            try:
-                subprocess.check_output(f"fuser -k {str(self.database.joinpath('cache.starrydb').resolve())}", shell=True, stderr=subprocess.STDOUT, universal_newlines=True)
-            except:
-                pass
-
-            try:
-                os.system(f"memcached -d -u root -a 0777 -D : -C -m {int(cache_size)} -s {str(self.database.joinpath('cache.starrydb').resolve())}")
-
-                time.sleep(1)
-
-                self.cache = LibMemcachedClient(str(self.database.joinpath('cache.starrydb').resolve()))
-            except Exception as e:
-                self.logger.error(f"Caught exception: {e.__doc__}({e})")
-
-                self.cache = None
-
-        return (True, "")
-
-    def clearCache(self):
-        if self.cache is not None:
-            try:
-                self.cache.flush_all()
-            except:
-                pass
-
-            try:
-                subprocess.check_output(f"fuser -k {str(self.database.joinpath('cache.starrydb').resolve())}", shell=True, stderr=subprocess.STDOUT, universal_newlines=True)
-            except:
-                pass
-
-        return (True, "")
-
     def get(self, key):
         if type(key) is not list:
             key = [key]
@@ -596,24 +594,22 @@ class StarryDepot(object):
 
     def clear(self):
         for elem in self.database.glob("*"):
-            if elem.is_file():
-                try:
-                    elem.unlink()
-                except Exception as e:
-                    self.logger.error(f"Caught exception: {e.__doc__}({e})")
-                    return (False, f"Caught exception: {e.__doc__}({e})")
-            elif elem.isdir():
+            if elem.suffix == ".mpb":
+                self._deleteCache(elem.stem)
+
+                if elem.is_file():
+                    try:
+                        elem.unlink()
+                    except Exception as e:
+                        self.logger.error(f"Caught exception: {e.__doc__}({e})")
+                        return (False, f"Caught exception: {e.__doc__}({e})")
+            elif elem.name == ".backup" and elem.isdir():
                 try:
                     shutil.rmtree(elem)
                 except Exception as e:
                     self.logger.error(f"Caught exception: {e.__doc__}({e})")
                     return (False, f"Caught exception: {e.__doc__}({e})")
 
-        try:
-            self.cache.flush_all()
-        except:
-            pass
-
         self.write_queue.clear()
         self.read_queue.clear()
 
@@ -624,7 +620,7 @@ class StarryDepot(object):
             return None
 
         try:
-            value = self.cache.get(key)
+            value = self.cache.get(f"{self.index}:{key}")
         except:
             return None
 
@@ -635,7 +631,7 @@ class StarryDepot(object):
             value = msgpack.unpackb(value, strict_map_key=False)
         except:
             try:
-                self.cache.delete(key)
+                self.cache.delete(f"{self.index}:{key}")
             except:
                 pass
 
@@ -646,7 +642,7 @@ class StarryDepot(object):
     def _setCache(self, key, value):
         if self.cache is not None:
             try:
-                self.cache.set(key, value)
+                self.cache.set(f"{self.index}:{key}", value)
             except:
                 return False
 
@@ -655,7 +651,7 @@ class StarryDepot(object):
     def _deleteCache(self, key):
         if self.cache is not None:
             try:
-                self.cache.delete(key)
+                self.cache.delete(f"{self.index}:{key}")
             except:
                 return False
 
